@@ -2,7 +2,7 @@
  * Copyright (c) 1999-2000 Image Power, Inc. and the University of
  *   British Columbia.
  * Copyright (c) 2001-2003 Michael David Adams.
- * Copyright (c) 2005-2006 artofcode LLC.
+ * Copyright (c) 2005-2006 Artifex Software, Inc.
  *
  * All rights reserved.
  */
@@ -66,7 +66,7 @@
 /*
  * Quadrature Mirror-Image Filter Bank (QMFB) Library
  *
- * $Id: jpc_qmfb.c,v 1.4 2007/05/07 11:22:21 Arabidopsis Exp $
+ * $Id: jpc_qmfb.c,v 1.5 2007/09/11 15:25:14 Arabidopsis Exp $
  */
 
 /******************************************************************************\
@@ -85,7 +85,7 @@
 #include "jpc_math.h"
 
 #ifndef USE_ASM_WIN32
-# if defined(_WIN32) && !defined(_WIN64)
+# if defined(_WIN32) && !defined(_WIN64) && ! defined(__BORLANDC__)
 #  define USE_ASM_WIN32
 # endif
 #endif
