@@ -16,7 +16,7 @@
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
-/* $Id: gdevddrw.c,v 1.11 2008/03/23 15:27:54 Arabidopsis Exp $ */
+/* $Id: gdevddrw.c,v 1.12 2008/05/04 14:34:57 Arabidopsis Exp $ */
 /* Default polygon and image drawing device procedures */
 #include "math_.h"
 #include "memory_.h"
@@ -612,6 +612,8 @@ gx_default_fill_parallelogram(gx_device * dev,
 	gs_int_rect r;
 
 	INT_RECT_FROM_PARALLELOGRAM(&r, px, py, ax, ay, bx, by);
+	vd_rect(int2fixed(r.p.x), int2fixed(r.p.y), int2fixed(r.q.x), int2fixed(r.q.y),
+		    1, (int)pdevc->colors.pure);
 	return gx_fill_rectangle_device_rop(r.p.x, r.p.y, r.q.x - r.p.x,
 					    r.q.y - r.p.y, pdevc, dev, lop);
     }
