@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gdevpdfu.c,v 1.12 2008/03/23 15:28:09 Arabidopsis Exp $ */
+/* $Id: gdevpdfu.c,v 1.13 2008/05/04 14:34:52 Arabidopsis Exp $ */
 /* Output utilities for PDF-writing driver */
 #include "memory_.h"
 #include "jpeglib_.h"		/* for sdct.h */
@@ -2075,7 +2075,7 @@ pdf_write_font_bbox_float(gx_device_pdf *pdev, const gs_rect *pbox)
     float x = pbox->q.x + ((pbox->p.x == pbox->q.x) ? 1000 : 0);
     float y = pbox->q.y + ((pbox->p.y == pbox->q.y) ? 1000 : 0);
 
-    pprintg4(s, "/FontBBox[%f %f %f %f]",
+    pprintg4(s, "/FontBBox[%g %g %g %g]",
 	     pbox->p.x, pbox->p.y, x, y);
     return 0;
 }
