@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gdevpdtf.h,v 1.10 2008/03/23 15:28:04 Arabidopsis Exp $ */
+/* $Id: gdevpdtf.h,v 1.11 2008/05/04 14:34:47 Arabidopsis Exp $ */
 /* Font and CMap resource structure and API for pdfwrite */
 
 #ifndef gdevpdtf_INCLUDED
@@ -434,11 +434,6 @@ int pdf_compute_BaseFont(gx_device_pdf *pdev, pdf_font_resource_t *pdfont, bool
  */
 int pdf_close_text_document(gx_device_pdf *pdev); /* in gdevpdtw.c */
 
-/*
- * Choose a name for embedded font.
- */
-const gs_font_name *pdf_choose_font_name(gs_font *font, bool key_name);
-
 /*
  * Convert True Type fonts into CID fonts for PDF/A.
  */
