@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gdevpdti.c,v 1.9 2007/09/11 15:23:49 Arabidopsis Exp $ */
+/* $Id: gdevpdti.c,v 1.10 2008/03/23 15:27:45 Arabidopsis Exp $ */
 /* Bitmap font implementation for pdfwrite */
 #include "memory_.h"
 #include "string_.h"
@@ -77,14 +77,14 @@ gs_private_st_ptrs1(st_pdf_bitmap_fonts, pdf_bitmap_fonts_t,
   "pdf_bitmap_fonts_t", pdf_bitmap_fonts_enum_ptrs,
   pdf_bitmap_fonts_reloc_ptrs, open_font);
 
-inline private long
+static inline long
 pdf_char_proc_id(const pdf_char_proc_t *pcp)
 {
     return pdf_resource_id((const pdf_resource_t *)pcp);
 }
 
 /* Assign a code for a char_proc. */
-private int
+static int
 assign_char_code(gx_device_pdf * pdev, gs_text_enum_t *pte)
 {
     pdf_bitmap_fonts_t *pbfs = pdev->text->bitmap_fonts;
@@ -244,7 +244,7 @@ pdf_char_image_y_offset(const gx_device_pdf *pdev, int x, int y, int h)
 }
 
 /* Attach a CharProc to a font. */
-private int
+static int
 pdf_attach_charproc(gx_device_pdf * pdev, pdf_font_resource_t *pdfont, pdf_char_proc_t *pcp,
 		    gs_glyph glyph, gs_char char_code, const gs_const_string *gnstr)
 {
@@ -485,11 +485,11 @@ pdf_set_charproc_attrs(gx_device_pdf *pdev, gs_font *font, const double *pw, int
 	is defined to paint glyphs with the current color."
 	However comparefiles/Bug687044.ps doesn't follow that. */
 	pdev->skip_colors = false; 
-	pprintg2(pdev->strm, "%g %g d0\n", (float)pw[0], (float)pw[1]);
+	pprintg1(pdev->strm, "%g 0 d0\n", (float)pw[0]);
     } else {
 	pdev->skip_colors = true;
 	pprintg6(pdev->strm, "%g %g %g %g %g %g d1\n", 
-	    (float)pw[0], (float)pw[1], (float)pw[2], 
+	    (float)pw[0], (float)0.0, (float)pw[2], 
 	    (float)pw[3], (float)pw[4], (float)pw[5]);
 	pdfont->u.simple.s.type3.cached[ch >> 3] |= 0x80 >> (ch & 7);
     }
@@ -607,6 +607,7 @@ pdf_enter_substream(gx_device_pdf *pdev, pdf_resource_type_t rtype,
     pdev->sbstack[sbstack_ptr].accumulating_a_global_object = pdev->accumulating_a_global_object;
     pdev->sbstack[sbstack_ptr].pres_soft_mask_dict = pdev->pres_soft_mask_dict;
     pdev->sbstack[sbstack_ptr].objname = pdev->objname;
+    pdev->sbstack[sbstack_ptr].last_charpath_op = pdev->last_charpath_op;
     pdev->skip_colors = false;
     pdev->charproc_just_accumulated = false;
     pdev->pres_soft_mask_dict = NULL;
@@ -618,6 +619,7 @@ pdf_enter_substream(gx_device_pdf *pdev, pdf_resource_type_t rtype,
     pdev->font3 = 0;
     pdev->context = PDF_IN_STREAM;
     pdev->accumulating_substream_resource = pres;
+    pdev->last_charpath_op = 0;
     pdf_reset_graphics(pdev);
     *ppres = pres;
     return 0;
@@ -666,6 +668,7 @@ pdf_exit_substream(gx_device_pdf *pdev)
     pdev->accumulating_a_global_object = pdev->sbstack[sbstack_ptr].accumulating_a_global_object;
     pdev->pres_soft_mask_dict = pdev->sbstack[sbstack_ptr].pres_soft_mask_dict;
     pdev->objname = pdev->sbstack[sbstack_ptr].objname;
+    pdev->last_charpath_op = pdev->sbstack[sbstack_ptr].last_charpath_op;
     pdev->sbstack_depth = sbstack_ptr;
     code1 = pdf_restore_viewer_state(pdev, NULL);
     if (code1 < 0 && code >= 0)
@@ -673,7 +676,7 @@ pdf_exit_substream(gx_device_pdf *pdev)
     return code;
 }
 
-private bool 
+static bool 
 pdf_is_same_charproc_attrs1(gx_device_pdf *pdev, pdf_char_proc_t *pcp0, pdf_char_proc_t *pcp1)
 {
     if (pcp0->real_width.x != pcp1->real_width.x)
@@ -695,7 +698,7 @@ typedef struct charproc_compatibility_data_s {
     gs_font *font;
 } charproc_compatibility_data_t;
 
-private bool
+static bool
 is_char_code_used(pdf_font_resource_t *pdfont, gs_char char_code)
 {
     pdf_char_proc_ownership_t *pcpo;
@@ -708,7 +711,7 @@ is_char_code_used(pdf_font_resource_t *pdfont, gs_char char_code)
     return false;
 }
 
-private int 
+static int 
 pdf_is_charproc_compatible(gx_device_pdf * pdev, pdf_resource_t *pres0, pdf_resource_t *pres1)
 {
     charproc_compatibility_data_t *data = (charproc_compatibility_data_t *)pdev->find_resource_param;
@@ -772,7 +775,7 @@ pdf_is_charproc_compatible(gx_device_pdf * pdev, pdf_resource_t *pres0, pdf_reso
     return 1;
 }
 
-private int 
+static int 
 pdf_find_same_charproc_aux(gx_device_pdf *pdev, 
 	    pdf_font_resource_t **ppdfont, pdf_char_proc_t **ppcp)
 {
@@ -802,7 +805,7 @@ pdf_find_same_charproc_aux(gx_device_pdf *pdev,
     }
     return pdf_find_same_resource(pdev, resourceCharProc, (pdf_resource_t **)ppcp, pdf_is_charproc_compatible);
 }
-private int 
+static int 
 pdf_find_same_charproc(gx_device_pdf *pdev, 
 	    pdf_font_resource_t **ppdfont, const pdf_char_glyph_pairs_t *cgp, 
 	    pdf_char_proc_t **ppcp, gs_glyph glyph, gs_char char_code,
@@ -823,7 +826,7 @@ pdf_find_same_charproc(gx_device_pdf *pdev,
     return code;
 }
 
-private bool
+static bool
 pdf_is_charproc_defined(gx_device_pdf *pdev, pdf_font_resource_t *pdfont, gs_char ch)
 {
     pdf_char_proc_ownership_t *pcpo;
@@ -835,7 +838,7 @@ pdf_is_charproc_defined(gx_device_pdf *pdev, pdf_font_resource_t *pdfont, gs_cha
     return false;
 }
 
-private int
+static int
 complete_adding_char(gx_device_pdf *pdev, gs_font *font, 
 		     gs_glyph glyph, gs_char ch, pdf_char_proc_t *pcp,
 		     const gs_const_string *gnstr)
@@ -876,7 +879,7 @@ complete_adding_char(gx_device_pdf *pdev, gs_font *font,
     return 0;
 }
 
-private int
+static int
 pdf_char_widths_from_charprocs(gx_device_pdf *pdev, gs_font *font)
 {
     pdf_font_resource_t *pdfont;
