@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gdevpdts.c,v 1.9 2008/03/23 15:28:03 Arabidopsis Exp $ */
+/* $Id: gdevpdts.c,v 1.10 2008/05/04 14:34:47 Arabidopsis Exp $ */
 /* Text state management for pdfwrite */
 #include "math_.h"
 #include "memory_.h"
@@ -526,7 +526,8 @@ pdf_render_mode_uses_stroke(const gx_device_pdf *pdev,
 			    const pdf_text_state_values_t *ptsv)
 {
     return (pdev->text->text_state->in.render_mode != ptsv->render_mode &&
-	    ptsv->render_mode != 0);
+	    ptsv->render_mode == 1 || ptsv->render_mode == 2 ||
+	    ptsv->render_mode == 5 || ptsv->render_mode == 6);
 }
 
 /*
