@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
   This file is part of GNU ghostscript
@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gsargs.h,v 1.6 2007/08/01 14:26:01 jemarch Exp $ */
+/* $Id: gsargs.h,v 1.7 2007/09/11 15:24:02 Arabidopsis Exp $ */
 /* Command line argument list management */
 
 #ifndef gsargs_INCLUDED
@@ -35,6 +35,7 @@ typedef struct arg_source_s {
     bool is_file;
     union _u {
 	struct _su {
+	    bool parsed;	/* true for "pushed-back" argument, not to be parsed again */
 	    char *chars;	/* original string */
 	    gs_memory_t *memory;  /* if non-0, free chars when done with it */
 	    const char *str;	/* string being read */
@@ -63,13 +64,11 @@ void arg_init(arg_list * pal, const char **argv, int argc,
  * This may also be used (once) to "unread" the last argument.
  * If mem != 0, it is used to free the string when we are done with it.
  * Return 0 on success, non-zero on failure
- * NB: pushing args has the side effect of changing the parsing algoritm to
- * space delimited instead of argument string delimited.
  */
-int arg_push_memory_string(arg_list * pal, char *str, gs_memory_t * mem);
+int arg_push_memory_string(arg_list * pal, char *str, bool parsed, gs_memory_t * mem);
 
-#define arg_push_string(pal, str)\
-  arg_push_memory_string(pal, str, (gs_memory_t *)0);
+#define arg_push_string(pal, str, parsed)\
+  arg_push_memory_string(pal, str, parsed, (gs_memory_t *)0);
 
 /* Clean up an arg list before exiting. */
 void arg_finit(arg_list * pal);
