@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2007 Artifex Software, Inc.
+/* Copyright (C) 2001-2008 Artifex Software, Inc.
    All Rights Reserved.
   
   This file is part of GNU ghostscript
@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gscdef.c,v 1.12 2008/03/23 15:27:39 Arabidopsis Exp $ */
+/* $Id: gscdef.c,v 1.13 2008/05/04 14:34:41 Arabidopsis Exp $ */
 /* Configuration scalars */
 
 #include "std.h"
@@ -33,25 +33,25 @@
 #  define GS_BUILDTIME\
 	0			/* should be set in the makefile */
 #endif
-CONFIG_CONST long gs_buildtime = GS_BUILDTIME;
+const long gs_buildtime = GS_BUILDTIME;
 
 #ifndef GS_COPYRIGHT
 #  define GS_COPYRIGHT\
-	"Copyright (C) 2007 Artifex Software, Inc.  All rights reserved."
+	"Copyright (C) 2008 Artifex Software, Inc.  All rights reserved."
 #endif
-const char *CONFIG_CONST gs_copyright = GS_COPYRIGHT;
+const char *const gs_copyright = GS_COPYRIGHT;
 
 #ifndef GS_PRODUCTFAMILY
 #  define GS_PRODUCTFAMILY\
 	"GNU Ghostscript"
 #endif
-const char *CONFIG_CONST gs_productfamily = GS_PRODUCTFAMILY;
+const char *const gs_productfamily = GS_PRODUCTFAMILY;
 
 #ifndef GS_PRODUCT
 #  define GS_PRODUCT\
 	GS_PRODUCTFAMILY
 #endif
-const char *CONFIG_CONST gs_product = GS_PRODUCT;
+const char *const gs_product = GS_PRODUCT;
 
 const char *
 gs_program_name(void)
@@ -60,7 +60,7 @@ gs_program_name(void)
 }
 
 /* GS_VERSION must be defined in the Makefile. */
-CONFIG_CONST long gs_version = GS_VERSION;
+const long gs_version = GS_VERSION;
 
 long gs_version_number(void)
 {
@@ -68,7 +68,7 @@ long gs_version_number(void)
 }
 
 /* GS_REVISION must be defined in the makefile. */
-CONFIG_CONST long gs_revision = GS_REVISION;
+const long gs_revision = GS_REVISION;
 
 long
 gs_revision_number(void)
@@ -77,13 +77,13 @@ gs_revision_number(void)
 }
 
 /* GS_REVISIONDATE must be defined in the makefile. */
-CONFIG_CONST long gs_revisiondate = GS_REVISIONDATE;
+const long gs_revisiondate = GS_REVISIONDATE;
 
 #ifndef GS_SERIALNUMBER
 #  define GS_SERIALNUMBER\
 	42			/* a famous number */
 #endif
-CONFIG_CONST long gs_serialnumber = GS_SERIALNUMBER;
+const long gs_serialnumber = GS_SERIALNUMBER;
 
 /* ---------------- Installation directories and files ---------------- */
 
