@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gscdevn.c,v 1.12 2008/03/23 15:28:17 Arabidopsis Exp $ */
+/* $Id: gscdevn.c,v 1.13 2008/05/04 14:34:56 Arabidopsis Exp $ */
 /* DeviceN color space and operation definition */
 
 #include "memory_.h"
@@ -381,11 +381,10 @@ gx_concretize_DeviceN(const gs_client_color * pc, const gs_color_space * pcs,
 	code = cs_concretize_color(&cc, pacs, pconc, pis);
     }
     else {
-	float ftemp;
 	int i;
 
 	for (i = pcs->params.device_n.num_components; --i >= 0;)
-	    pconc[i] = unit_frac(pc->paint.values[i], ftemp);
+	    pconc[i] = gx_unit_frac(pc->paint.values[i]);
 	return 0;
     }
     return (code < 0 || tcode == 0 ? code : tcode);
