@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
   This file is part of GNU ghostscript
@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gserror.h,v 1.7 2007/08/01 14:26:05 jemarch Exp $ */
+/* $Id: gserror.h,v 1.9 2007/09/11 15:24:36 Arabidopsis Exp $ */
 /* Error return macros */
 
 #ifndef gserror_INCLUDED
@@ -30,9 +30,15 @@ int gs_log_error(int, const char *, int);
 #define gs_note_error(err) gs_log_error(err, __FILE__, __LINE__)
 #define return_error(err) return gs_note_error(err)
 
-# if defined(__WIN32__)
-#define __func__ __FUNCTION__
-# endif
+#if !defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901L
+#  if defined(__FUNCTION__)
+#    define __func__ __FUNCTION__
+#  elif defined(__FUNC__)
+#    define __func__ __FUNC__
+#  else
+#    define __func__ "<unknown>"
+#  endif
+#endif
 
 /*
  * Error reporting macros.
