@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gsfcmap.c,v 1.10 2007/09/11 15:24:39 Arabidopsis Exp $ */
+/* $Id: gsfcmap.c,v 1.11 2008/03/23 15:27:59 Arabidopsis Exp $ */
 /* CMap character decoding */
 #include "memory_.h"
 #include "string_.h"
@@ -47,7 +47,7 @@ gs_private_st_suffix_add0_local(st_cmap_identity, gs_cmap_identity_t,
 /*
  * Create an Identity CMap.
  */
-private uint
+static uint
 get_integer_bytes(const byte *src, int count)
 {
     uint v = 0;
@@ -57,7 +57,7 @@ get_integer_bytes(const byte *src, int count)
 	v = (v << 8) + src[i];
     return v;
 }
-private int
+static int
 identity_decode_next(const gs_cmap_t *pcmap, const gs_const_string *str,
 		     uint *pindex, uint *pfidx,
 		     gs_char *pchr, gs_glyph *pglyph)
@@ -78,7 +78,7 @@ identity_decode_next(const gs_cmap_t *pcmap, const gs_const_string *str,
     *pfidx = 0;
     return pcimap->code;
 }
-private int
+static int
 identity_next_range(gs_cmap_ranges_enum_t *penum)
 {
     if (penum->index == 0) {
@@ -93,15 +93,15 @@ identity_next_range(gs_cmap_ranges_enum_t *penum)
     }
     return 1;
 }
-private const gs_cmap_ranges_enum_procs_t identity_range_procs = {
+static const gs_cmap_ranges_enum_procs_t identity_range_procs = {
     identity_next_range
 };
-private void
+static void
 identity_enum_ranges(const gs_cmap_t *pcmap, gs_cmap_ranges_enum_t *pre)
 {
     gs_cmap_ranges_enum_setup(pre, pcmap, &identity_range_procs);
 }
-private int
+static int
 identity_next_lookup(gs_cmap_lookups_enum_t *penum)
 {
     if (penum->index[0] == 0) {
@@ -123,12 +123,12 @@ identity_next_lookup(gs_cmap_lookups_enum_t *penum)
     }
     return 1;
 }
-private int
+static int
 no_next_lookup(gs_cmap_lookups_enum_t *penum)
 {
     return 1;
 }
-private int
+static int
 identity_next_entry(gs_cmap_lookups_enum_t *penum)
 {
     const gs_cmap_identity_t *const pcimap =
@@ -146,13 +146,13 @@ identity_next_entry(gs_cmap_lookups_enum_t *penum)
     return 1;
 }
 
-private const gs_cmap_lookups_enum_procs_t identity_lookup_procs = {
+static const gs_cmap_lookups_enum_procs_t identity_lookup_procs = {
     identity_next_lookup, identity_next_entry
 };
 const gs_cmap_lookups_enum_procs_t gs_cmap_no_lookups_procs = {
     no_next_lookup, 0
 };
-private void
+static void
 identity_enum_lookups(const gs_cmap_t *pcmap, int which,
 		      gs_cmap_lookups_enum_t *pre)
 {
@@ -160,17 +160,17 @@ identity_enum_lookups(const gs_cmap_t *pcmap, int which,
 			       (which ? &gs_cmap_no_lookups_procs :
 				&identity_lookup_procs));
 }
-private bool
+static bool
 identity_is_identity(const gs_cmap_t *pcmap, int font_index_only)
 {
     return true;
 }
 
-private const gs_cmap_procs_t identity_procs = {
+static const gs_cmap_procs_t identity_procs = {
     identity_decode_next, identity_enum_ranges, identity_enum_lookups, identity_is_identity
 };
 
-private int
+static int
 gs_cmap_identity_alloc(gs_cmap_t **ppcmap, int num_bytes, int varying_bytes,
 		       int return_code, const char *cmap_name, int wmode,
 		       gs_memory_t *mem)
@@ -418,7 +418,7 @@ gs_cmap_compute_identity(const gs_cmap_t *pcmap, int font_index_only)
  * allows to write code pairs into the closure data.
  */
 
-private const int gs_cmap_ToUnicode_code_bytes = 2;
+static const int gs_cmap_ToUnicode_code_bytes = 2;
 
 typedef struct gs_cmap_ToUnicode_s {
     GS_CMAP_COMMON;
@@ -431,7 +431,7 @@ gs_private_st_suffix_add0(st_cmap_ToUnicode, gs_cmap_ToUnicode_t,
     "gs_cmap_ToUnicode_t", cmap_ToUnicode_enum_ptrs, cmap_ToUnicode_reloc_ptrs,
     st_cmap);
 
-private int
+static int
 gs_cmap_ToUnicode_next_range(gs_cmap_ranges_enum_t *penum)
 {   const gs_cmap_ToUnicode_t *cmap = (gs_cmap_ToUnicode_t *)penum->cmap;
     if (penum->index == 0) {
@@ -444,11 +444,11 @@ gs_cmap_ToUnicode_next_range(gs_cmap_ranges_enum_t *penum)
     return 1;
 }
 
-private const gs_cmap_ranges_enum_procs_t gs_cmap_ToUnicode_range_procs = {
+static const gs_cmap_ranges_enum_procs_t gs_cmap_ToUnicode_range_procs = {
     gs_cmap_ToUnicode_next_range
 };
 
-private int
+static int
 gs_cmap_ToUnicode_decode_next(const gs_cmap_t *pcmap, const gs_const_string *str,
 		     uint *pindex, uint *pfidx,
 		     gs_char *pchr, gs_glyph *pglyph)
@@ -456,13 +456,13 @@ gs_cmap_ToUnicode_decode_next(const gs_cmap_t *pcmap, const gs_const_string *str
     return_error(gs_error_unregistered);
 }
 
-private void
+static void
 gs_cmap_ToUnicode_enum_ranges(const gs_cmap_t *pcmap, gs_cmap_ranges_enum_t *pre)
 {
     gs_cmap_ranges_enum_setup(pre, pcmap, &gs_cmap_ToUnicode_range_procs);
 }
 
-private int
+static int
 gs_cmap_ToUnicode_next_lookup(gs_cmap_lookups_enum_t *penum)
 {   const gs_cmap_ToUnicode_t *cmap = (gs_cmap_ToUnicode_t *)penum->cmap;
     
@@ -479,7 +479,7 @@ gs_cmap_ToUnicode_next_lookup(gs_cmap_lookups_enum_t *penum)
     return 0;
 }
 
-private int
+static int
 gs_cmap_ToUnicode_next_entry(gs_cmap_lookups_enum_t *penum)
 {   const gs_cmap_ToUnicode_t *cmap = (gs_cmap_ToUnicode_t *)penum->cmap;
     const uchar *map = cmap->glyph_name_data;
@@ -515,11 +515,11 @@ gs_cmap_ToUnicode_next_entry(gs_cmap_lookups_enum_t *penum)
     return 0;
 }
 
-private const gs_cmap_lookups_enum_procs_t gs_cmap_ToUnicode_lookup_procs = {
+static const gs_cmap_lookups_enum_procs_t gs_cmap_ToUnicode_lookup_procs = {
     gs_cmap_ToUnicode_next_lookup, gs_cmap_ToUnicode_next_entry
 };
 
-private void
+static void
 gs_cmap_ToUnicode_enum_lookups(const gs_cmap_t *pcmap, int which,
 		      gs_cmap_lookups_enum_t *pre)
 {
@@ -528,13 +528,13 @@ gs_cmap_ToUnicode_enum_lookups(const gs_cmap_t *pcmap, int which,
 				&gs_cmap_ToUnicode_lookup_procs));
 }
 
-private bool
+static bool
 gs_cmap_ToUnicode_is_identity(const gs_cmap_t *pcmap, int font_index_only)
 {   const gs_cmap_ToUnicode_t *cmap = (gs_cmap_ToUnicode_t *)pcmap;
     return cmap->is_identity;
 }
 
-private const gs_cmap_procs_t gs_cmap_ToUnicode_procs = {
+static const gs_cmap_procs_t gs_cmap_ToUnicode_procs = {
     gs_cmap_ToUnicode_decode_next,
     gs_cmap_ToUnicode_enum_ranges,
     gs_cmap_ToUnicode_enum_lookups,
