@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gsfunc4.c,v 1.10 2007/09/11 15:24:21 Arabidopsis Exp $ */
+/* $Id: gsfunc4.c,v 1.11 2008/03/23 15:28:15 Arabidopsis Exp $ */
 /* Implementation of FunctionType 4 (PostScript Calculator) Functions */
 #include "math_.h"
 #include "memory_.h"
@@ -65,7 +65,7 @@ typedef struct calc_value_s {
 } calc_value_t;
 
 /* Store a float. */
-private inline void
+static inline void
 store_float(calc_value_t *vsp, floatp f)
 {
     vsp->value.f = f;
@@ -107,7 +107,7 @@ typedef enum {
 } gs_PtCr_typed_opcode_t;
 
 /* Evaluate a PostScript Calculator function. */
-private int
+static int
 fn_PtCr_evaluate(const gs_function_t *pfn_common, const float *in, float *out)
 {
     const gs_function_PtCr_t *pfn = (const gs_function_PtCr_t *)pfn_common;
@@ -566,7 +566,7 @@ fn_PtCr_evaluate(const gs_function_t *pfn_common, const float *in, float *out)
 }
 
 /* Test whether a PostScript Calculator function is monotonic. */
-private int
+static int
 fn_PtCr_is_monotonic(const gs_function_t * pfn_common,
 		     const float *lower, const float *upper, uint *mask)
 {
@@ -581,7 +581,7 @@ fn_PtCr_is_monotonic(const gs_function_t * pfn_common,
 }
 
 /* Write the function definition in symbolic form on a stream. */
-private int
+static int
 calc_put_ops(stream *s, const byte *ops, uint size)
 {
     const byte *p;
@@ -660,7 +660,7 @@ calc_put_ops(stream *s, const byte *ops, uint size)
     spputc(s, '}');
     return 0;
 }
-private int
+static int
 calc_put(stream *s, const gs_function_PtCr_t *pfn)
 {
     calc_put_ops(s, pfn->params.ops.data, pfn->params.ops.size - 1);
@@ -668,7 +668,7 @@ calc_put(stream *s, const gs_function_PtCr_t *pfn)
 }
 
 /* Access the symbolic definition as a DataSource. */
-private int
+static int
 calc_access(const gs_data_source_t *psrc, ulong start, uint length,
 	    byte *buf, const byte **ptr)
 {
@@ -705,7 +705,7 @@ calc_access(const gs_data_source_t *psrc, ulong start, uint length,
 }
 
 /* Return PostScript Calculator function information. */
-private void
+static void
 fn_PtCr_get_info(const gs_function_t *pfn_common, gs_function_info_t *pfi)
 {
     const gs_function_PtCr_t *const pfn =
@@ -724,7 +724,7 @@ fn_PtCr_get_info(const gs_function_t *pfn_common, gs_function_info_t *pfi)
 }
 
 /* Make a scaled copy of a PostScript Calculator function. */
-private int
+static int
 fn_PtCr_make_scaled(const gs_function_PtCr_t *pfn, gs_function_PtCr_t **ppsfn,
 		    const gs_range_t *pranges, gs_memory_t *mem)
 {
@@ -795,7 +795,7 @@ gs_function_PtCr_free_params(gs_function_PtCr_params_t * params, gs_memory_t * m
 }
 
 /* Serialize. */
-private int
+static int
 gs_function_PtCr_serialize(const gs_function_t * pfn, stream *s)
 {
     uint n;
