@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
   This file is part of GNU ghostscript
@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gsptype1.h,v 1.6 2007/08/01 14:26:12 jemarch Exp $ */
+/* $Id: gsptype1.h,v 1.8 2007/09/11 15:24:35 Arabidopsis Exp $ */
 /* Client interface to PatternType 1 Patterns */
 
 #ifndef gsptype1_INCLUDED
@@ -26,6 +26,11 @@
 #include "gspcolor.h"
 #include "gxbitmap.h"
 
+#ifndef gx_device_color_DEFINED
+#  define gx_device_color_DEFINED
+typedef struct gx_device_color_s gx_device_color;
+#endif
+
 /* ---------------- Types and structures ---------------- */
 
 /* PatternType 1 template */
@@ -84,6 +89,9 @@ int gs_makepattern(gs_client_color *, const gs_client_pattern *,
 		   const gs_matrix *, gs_state *, gs_memory_t *);
 const gs_client_pattern *gs_getpattern(const gs_client_color *);
 
+/* Check device color for Pattern Type 1. */
+bool gx_dc_is_pattern1_color(const gx_device_color *pdevc);
+
 /*
  * Make a pattern from a bitmap or pixmap. The pattern may be colored or
  * uncolored, as determined by the mask operand. This code is intended
