@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gxccman.c,v 1.10 2007/09/11 15:24:29 Arabidopsis Exp $ */
+/* $Id: gxccman.c,v 1.11 2008/03/23 15:28:13 Arabidopsis Exp $ */
 /* Character cache management routines for Ghostscript library */
 #include "gx.h"
 #include "memory_.h"
@@ -53,21 +53,21 @@ gs_private_st_simple(st_font_cache_bytes, byte, "font cache bytes");
 /* GC procedures */
 /* We do all the work in font_dir_enum/reloc_ptrs in gsfont.c. */
 /* See gxfcache.h for details. */
-private 
+static 
 ENUM_PTRS_BEGIN(cc_ptr_enum_ptrs) return 0;
 
 ENUM_PTRS_END
-private RELOC_PTRS_BEGIN(cc_ptr_reloc_ptrs)
+static RELOC_PTRS_BEGIN(cc_ptr_reloc_ptrs)
 {
 }
 RELOC_PTRS_END
 
 /* Forward references */
-private gx_xfont * lookup_xfont_by_name(gx_device *, const gx_xfont_procs *, gs_font_name *, int, const cached_fm_pair *, const gs_matrix *);
-private cached_char *alloc_char(gs_font_dir *, ulong);
-private cached_char *alloc_char_in_chunk(gs_font_dir *, ulong);
-private void hash_remove_cached_char(gs_font_dir *, uint);
-private void shorten_cached_char(gs_font_dir *, cached_char *, uint);
+static gx_xfont * lookup_xfont_by_name(gx_device *, const gx_xfont_procs *, gs_font_name *, int, const cached_fm_pair *, const gs_matrix *);
+static int alloc_char(gs_font_dir *, ulong, cached_char **);
+static int alloc_char_in_chunk(gs_font_dir *, ulong, cached_char **);
+static void hash_remove_cached_char(gs_font_dir *, uint);
+static void shorten_cached_char(gs_font_dir *, cached_char *, uint);
 
 /* ====== Initialization ====== */
 
@@ -168,7 +168,7 @@ gx_purge_selected_cached_chars(gs_font_dir * dir,
 
 /* ====== font-matrix pair lists ====== */
 
-private int
+static int
 fm_pair_remove_from_list(gs_font_dir * dir, cached_fm_pair *pair, uint *head)
 {
     if (dir->fmcache.mdata + pair->index != pair)
@@ -194,7 +194,7 @@ fm_pair_remove_from_list(gs_font_dir * dir, cached_fm_pair *pair, uint *head)
     return 0;
 }
 
-private int
+static int
 fm_pair_insert_into_list(gs_font_dir * dir, cached_fm_pair *pair, uint *head)
 {
     if (dir->fmcache.mdata + pair->index != pair)
@@ -219,7 +219,7 @@ fm_pair_insert_into_list(gs_font_dir * dir, cached_fm_pair *pair, uint *head)
 
 /* ====== Font-level routines ====== */
 
-private int 
+static int 
 gx_attach_tt_interpreter(gs_font_dir * dir,
 	       gs_font_type42 *font, cached_fm_pair *pair,
 	       const gs_matrix * char_tm, const gs_log2_scale_point *log2_scale,
@@ -236,7 +236,7 @@ gx_attach_tt_interpreter(gs_font_dir * dir,
     m.yx = cyx;
     m.yy = cyy;
     m.tx = m.ty = 0;
-    pair->ttr = gx_ttfReader__create(dir->memory);
+    pair->ttr = gx_ttfReader__create(dir->memory->stable_memory);
     if (!pair->ttr)
 	return_error(gs_error_VMerror);
     /*  We could use a single the reader instance for all fonts ... */
@@ -250,7 +250,7 @@ gx_attach_tt_interpreter(gs_font_dir * dir,
     return code;
 }
 
-private inline bool
+static inline bool
 does_font_need_tt_interpreter(gs_font *font)
 {
     if (font->FontType == ft_TrueType || font->FontType == ft_CID_TrueType) {
@@ -449,19 +449,19 @@ gx_lookup_xfont(const gs_state * pgs, cached_fm_pair * pair, int encoding_index)
 /* Purge from the caches all references to a given font/matrix pair, */
 /* or just characters that depend on its xfont. */
 #define cpair ((cached_fm_pair *)vpair)
-private bool
+static bool
 purge_fm_pair_char(const gs_memory_t *mem, cached_char * cc, void *vpair)
 {
     return cc_pair(cc) == cpair;
 }
-private bool
+static bool
 purge_fm_pair_char_xfont(const gs_memory_t *mem, cached_char * cc, void *vpair)
 {
     return cc_pair(cc) == cpair && cpair->xfont == 0 && !cc_has_bits(cc);
 }
 #undef cpair
 
-private inline void
+static inline void
 gs_clean_fm_pair_attributes(gs_font_dir * dir, cached_fm_pair * pair)
 {
     if (pair->ttr)
@@ -525,7 +525,7 @@ gs_purge_fm_pair(gs_font_dir * dir, cached_fm_pair * pair, int xfont_only)
 /* Look up an xfont by name. */
 /* The caller must already have done get_xfont_device to get the proper */
 /* device to pass as the first argument to lookup_font. */
-private gx_xfont *
+static gx_xfont *
 lookup_xfont_by_name(gx_device * fdev, const gx_xfont_procs * procs,
       gs_font_name * pfstr, int encoding_index, const cached_fm_pair * pair,
 		     const gs_matrix * pmat)
@@ -559,10 +559,10 @@ lookup_xfont_by_name(gx_device * fdev, const gx_xfont_procs * procs,
  * not NULL, dev should be an alpha-buffer device with dev2 (an alpha
  * device) as target.
  */
-cached_char *
+int 
 gx_alloc_char_bits(gs_font_dir * dir, gx_device_memory * dev,
 		   gx_device_memory * dev2, ushort iwidth, ushort iheight,
-		   const gs_log2_scale_point * pscale, int depth)
+		   const gs_log2_scale_point * pscale, int depth, cached_char **pcc)
 {
     int log2_xscale = pscale->x;
     int log2_yscale = pscale->y;
@@ -575,7 +575,9 @@ gx_alloc_char_bits(gs_font_dir * dir, gx_device_memory * dev,
     gx_device_memory *pdev = dev;
     gx_device_memory *pdev2;  
     float HWResolution0 = 72, HWResolution1 = 72;  /* default for dev == NULL */
+    int code;
     
+    *pcc = 0;
     if (dev == NULL) {
 	mdev.memory = 0;
 	mdev.target = 0;
@@ -643,7 +645,10 @@ gx_alloc_char_bits(gs_font_dir * dir, gx_device_memory * dev,
 	dev->HWResolution[1] = HWResolution1 * (1 >> log2_yscale);
     }
     icdsize = isize + sizeof_cached_char;
-    cc = alloc_char(dir, icdsize);
+    code = alloc_char(dir, icdsize, &cc);
+    if (code < 0)
+	return code;
+    *pcc = cc;
     if (cc == 0)
 	return 0;
     if_debug4('k', "[k]adding char 0x%lx:%u(%u,%u)\n",
@@ -681,7 +686,7 @@ gx_alloc_char_bits(gs_font_dir * dir, gx_device_memory * dev,
     } else if (dev)
 	gx_open_cache_device(dev, cc);
 
-    return cc;
+    return 0;
 }
 
 /* Open the cache device. */
@@ -893,7 +898,7 @@ gx_add_char_bits(gs_font_dir * dir, cached_char * cc,
 }
 
 /* Purge from the caches all references to a given font. */
-private int
+static int
 gs_purge_font_from_char_caches_forced(gs_font * font, bool force)
 {
     gs_font_dir * dir;
@@ -968,11 +973,15 @@ gs_purge_font_from_char_caches_completely(gs_font * font)
 /* ------ Internal routines ------ */
 
 /* Allocate data space for a cached character, adding a new chunk if needed. */
-private cached_char *
-alloc_char(gs_font_dir * dir, ulong icdsize)
+static int
+alloc_char(gs_font_dir * dir, ulong icdsize, cached_char **pcc)
 {				/* Try allocating at the current position first. */
-    cached_char *cc = alloc_char_in_chunk(dir, icdsize);
+    cached_char *cc;
+    int code = alloc_char_in_chunk(dir, icdsize, &cc);
 
+    *pcc = cc;
+    if (code < 0)
+	return code;
     if (cc == 0) {
 	if (dir->ccache.bspace < dir->ccache.bmax) {	/* Allocate another chunk. */
 	    gs_memory_t *mem = dir->ccache.bits_memory;
@@ -1014,26 +1023,34 @@ alloc_char(gs_font_dir * dir, ulong icdsize)
 
 	    while ((dir->ccache.chunks = cck = cck->next) != cck_init) {
 		dir->ccache.cnext = 0;
-		cc = alloc_char_in_chunk(dir, icdsize);
-		if (cc != 0)
-		    return cc;
+		code = alloc_char_in_chunk(dir, icdsize, &cc);
+		if (code < 0)
+		    return code;
+		if (cc != 0) {
+		    *pcc = cc;
+		    return 0;
+		}
 	    }
 	}
 	dir->ccache.cnext = 0;
-	cc = alloc_char_in_chunk(dir, icdsize);
+	code = alloc_char_in_chunk(dir, icdsize, &cc);
+	if (code < 0)
+	    return code;
+	*pcc = cc;
     }
-    return cc;
+    return 0;
 }
 
 /* Allocate a character in the current chunk. */
-private cached_char *
-alloc_char_in_chunk(gs_font_dir * dir, ulong icdsize)
+static int
+alloc_char_in_chunk(gs_font_dir * dir, ulong icdsize, cached_char **pcc)
 {
     char_cache_chunk *cck = dir->ccache.chunks;
     cached_char_head *cch;
 
 #define cc ((cached_char *)cch)
 
+    *pcc = 0;
     while (gx_bits_cache_alloc((gx_bits_cache *) & dir->ccache,
 			       icdsize, &cch) < 0
 	) {
@@ -1051,9 +1068,13 @@ alloc_char_in_chunk(gs_font_dir * dir, ulong icdsize)
 
 	    if (pair != 0) {
 		uint chi = chars_head_index(cc->code, pair);
+		uint cnt = dir->ccache.table_mask + 1;
 
-		while (dir->ccache.table[chi & dir->ccache.table_mask] != cc)
+		while (dir->ccache.table[chi & dir->ccache.table_mask] != cc) {
 		    chi++;
+		    if (cnt-- == 0)
+			return_error(gs_error_unregistered); /* Must not happen. */
+		}
 		hash_remove_cached_char(dir, chi);
 	    }
 
@@ -1067,14 +1088,15 @@ alloc_char_in_chunk(gs_font_dir * dir, ulong icdsize)
 
     cc->chunk = cck;
     cc->loc = (byte *) cc - cck->data;
-    return cc;
+    *pcc = cc;
+    return 0;
 
 #undef cc
 }
 
 /* Remove the cached_char at a given index in the hash table. */
 /* In order not to slow down lookup, we relocate following entries. */
-private void
+static void
 hash_remove_cached_char(gs_font_dir * dir, uint chi)
 {
     uint mask = dir->ccache.table_mask;
@@ -1101,7 +1123,7 @@ hash_remove_cached_char(gs_font_dir * dir, uint chi)
 
 /* Shorten a cached character. */
 /* diff >= sizeof(cached_char_head). */
-private void
+static void
 shorten_cached_char(gs_font_dir * dir, cached_char * cc, uint diff)
 {
     gx_bits_cache_shorten((gx_bits_cache *) & dir->ccache, &cc->head,
