@@ -17,7 +17,7 @@
 
 */
 
-/*$Id: gxclist.c,v 1.12 2008/03/23 15:27:39 Arabidopsis Exp $ */
+/*$Id: gxclist.c,v 1.13 2008/05/04 14:34:42 Arabidopsis Exp $ */
 /* Command list document- and page-level code. */
 #include "memory_.h"
 #include "string_.h"
@@ -315,17 +315,21 @@ clist_init_states(gx_device * dev, byte * init_data, uint data_size)
     gx_device_clist_writer * const cdev =
 	&((gx_device_clist *)dev)->writer;
     ulong state_size = cdev->nbands * (ulong) sizeof(gx_clist_state);
+    /* Align to the natural boundary for ARM processors, bug 689600 */
+    long alignment = (-(long)init_data) & (sizeof(init_data) - 1);
 
     /*
      * The +100 in the next line is bogus, but we don't know what the
      * real check should be. We're effectively assuring that at least 100
      * bytes will be available to buffer command operands.
      */
-    if (state_size + sizeof(cmd_prefix) + cmd_largest_size + 100 > data_size)
+    if (state_size + sizeof(cmd_prefix) + cmd_largest_size + 100 + alignment > data_size)
 	return_error(gs_error_rangecheck);
+    /* The end buffer position is not affected by alignment */
+    cdev->cend = init_data + data_size;
+    init_data +=  alignment;
     cdev->states = (gx_clist_state *) init_data;
     cdev->cbuf = init_data + state_size;
-    cdev->cend = init_data + data_size;
     return 0;
 }
 
@@ -357,7 +361,7 @@ clist_init_data(gx_device * dev, byte * init_data, uint data_size)
     int code;
 
     /* Call create_buf_device to get the memory planarity set up. */
-    cdev->buf_procs.create_buf_device(&pbdev, target, NULL, NULL, clist_get_band_complexity(0, 0));
+    cdev->buf_procs.create_buf_device(&pbdev, target, 0, NULL, NULL, clist_get_band_complexity(0, 0));
     /* HACK - if the buffer device can't do copy_alpha, disallow */
     /* copy_alpha in the commmand list device as well. */
     if (dev_proc(pbdev, copy_alpha) == gx_no_copy_alpha)
