@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
   This file is part of GNU ghostscript
@@ -17,7 +17,7 @@
 
 */
 
-/*$Id: gxdcolor.h,v 1.6 2007/08/01 14:26:20 jemarch Exp $ */
+/*$Id: gxdcolor.h,v 1.8 2007/09/11 15:24:19 Arabidopsis Exp $ */
 /* Device color representation for Ghostscript */
 
 #ifndef gxdcolor_INCLUDED
@@ -33,7 +33,11 @@
 #ifndef gx_device_DEFINED
 #  define gx_device_DEFINED
 typedef struct gx_device_s gx_device;
+#endif
 
+#ifndef gs_imager_state_DEFINED
+#  define gs_imager_state_DEFINED
+typedef struct gs_imager_state_s gs_imager_state;
 #endif
 
 /*
