@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gxfill.c,v 1.12 2008/03/23 15:27:44 Arabidopsis Exp $ */
+/* $Id: gxfill.c,v 1.13 2008/05/04 14:34:47 Arabidopsis Exp $ */
 /* A topological spot decomposition algorithm with dropout prevention. */
 /* 
    This is a dramaticly reorganized and improved revision of the 
@@ -604,29 +604,39 @@ gx_default_fill_path(gx_device * pdev, const gs_imager_state * pis,
 	/*  We need a single clipping path here, because shadings and
 	    halftones don't take 2 paths. Compute the clipping path intersection.
 	*/
-	gx_clip_path cpath_intersection, cpath_with_shading_bbox;
-	const gx_clip_path *pcpath1, *pcpath2;
 	gs_imager_state *pis_noconst = (gs_imager_state *)pis; /* Break const. */
 
-	if (ppath != NULL) {
+	gx_clip_path cpath_intersection;
+	const gs_fixed_rect *pcbox = (pcpath == NULL ? NULL : cpath_is_rectangle(pcpath));
+	gs_fixed_rect shading_rect;
+	int shading_rect_code = gx_dc_pattern2_is_rectangular_cell(pdevc, pdev, &shading_rect);
+	    gs_fixed_rect clip_box;
+
+	if (shading_rect_code < 0)
+	    return shading_rect_code;
+	if (shading_rect_code != 0 && (pcpath == NULL || pcbox != NULL)) {
+	    if (pcbox != NULL) 
+		clip_box = *pcbox;
+	    else
+		(*dev_proc(pdev, get_clipping_box)) (pdev, &clip_box);
+	    rect_intersect(clip_box, shading_rect);
+	    code = gx_cpath_from_rectangle(&cpath_intersection, &clip_box);
+	} else if (pcpath != NULL) {
+	    /* either *pcpath is not a rectangle, or shading cell is not a rectangle.  */
 	    code = gx_cpath_init_local_shared(&cpath_intersection, pcpath, pdev->memory);
 	    if (code < 0)
 		return code;
-	    if (pcpath == NULL) {
-		gs_fixed_rect clip_box1;
-
-		(*dev_proc(pdev, get_clipping_box)) (pdev, &clip_box1);
-		code = gx_cpath_from_rectangle(&cpath_intersection, &clip_box1);
-	    }
-	    if (code >= 0)
-		code = gx_cpath_intersect_with_params(&cpath_intersection, ppath, params->rule, 
-			pis_noconst, params);
-	    pcpath1 = &cpath_intersection;
-	} else
-	    pcpath1 = pcpath;
-	pcpath2 = pcpath1;
-	if (code >= 0)
-	    code = gx_dc_pattern2_clip_with_bbox(pdevc, pdev, &cpath_with_shading_bbox, &pcpath1);
+	    if (gx_dc_is_pattern2_color(pdevc))
+		code = gx_dc_pattern2_clip_with_bbox_simple(pdevc, pdev, &cpath_intersection);
+	} else {
+	    /* Happens with a pattern1 color. */
+	    (*dev_proc(pdev, get_clipping_box)) (pdev, &clip_box);
+	    gx_cpath_init_local(&cpath_intersection, ppath->memory);
+	    code = gx_cpath_from_rectangle(&cpath_intersection, &clip_box);
+	}
+	if (ppath != NULL && code >= 0)
+	    code = gx_cpath_intersect_with_params(&cpath_intersection, ppath, params->rule, 
+		    pis_noconst, params);
 	/* Do fill : */
 	if (code >= 0) {
 	    gs_fixed_rect clip_box;
@@ -635,7 +645,7 @@ gx_default_fill_path(gx_device * pdev, const gs_imager_state * pis,
 	    gx_device *dev;
 	    gx_device_clip cdev;
 
-	    gx_cpath_outer_box(pcpath1, &clip_box);
+	    gx_cpath_outer_box(&cpath_intersection, &clip_box);
 	    cb.p.x = fixed2int_pixround(clip_box.p.x);
 	    cb.p.y = fixed2int_pixround(clip_box.p.y);
 	    cb.q.x = fixed2int_pixround(clip_box.q.x);
@@ -645,10 +655,10 @@ gx_default_fill_path(gx_device * pdev, const gs_imager_state * pis,
 		/* A special interaction with clist writer device : 
 		   pass the intersected clipping path. It uses an unusual call to
 		   fill_path with NULL device color. */
-		code = (*dev_proc(pdev, fill_path))(pdev, pis, ppath, params, NULL, pcpath1);
+		code = (*dev_proc(pdev, fill_path))(pdev, pis, ppath, params, NULL, &cpath_intersection);
 		dev = pdev;
 	    } else {
-		gx_make_clip_device_on_stack(&cdev, pcpath1, pdev);
+		gx_make_clip_device_on_stack(&cdev, &cpath_intersection, pdev);
 		dev = (gx_device *)&cdev;
 		if ((*dev_proc(pdev, pattern_manage))(pdev, 
 			gs_no_id, NULL, pattern_manage__shading_area) > 0)
@@ -660,10 +670,7 @@ gx_default_fill_path(gx_device * pdev, const gs_imager_state * pis,
 			cb.p.x, cb.p.y, cb.q.x - cb.p.x, cb.q.y - cb.p.y,
 			dev, pis->log_op, rs);
 	}
-	if (ppath != NULL)
-	    gx_cpath_free(&cpath_intersection, "shading_fill_cpath_intersection");
-	if (pcpath1 != pcpath2)
-	    gx_cpath_free(&cpath_with_shading_bbox, "shading_fill_cpath_intersection");
+	gx_cpath_free(&cpath_intersection, "shading_fill_cpath_intersection");
     } else {
 	bool got_dc = false;
         vd_save;
