@@ -17,11 +17,12 @@
 
 */
 
-/* $Id: gxiscale.c,v 1.11 2008/03/23 15:27:44 Arabidopsis Exp $ */
+/* $Id: gxiscale.c,v 1.12 2008/05/04 14:34:46 Arabidopsis Exp $ */
 /* Interpolated image procedures */
 #include "gx.h"
 #include "math_.h"
 #include "memory_.h"
+#include "stdint_.h"
 #include "gpcheck.h"
 #include "gserrors.h"
 #include "gxfixed.h"
@@ -41,6 +42,7 @@
 #include "siinterp.h"		/* for spatial interpolation */
 #include "siscale.h"		/* for Mitchell filtering */
 #include "sidscale.h"		/* for special case downscale filter */
+#include "vdtrace.h"
 
 /*
  * Define whether we are using Mitchell filtering or spatial
@@ -106,9 +108,17 @@ gs_image_class_0_interpolate(gx_image_enum * penum)
     iss.BitsPerComponentOut = sizeof(frac) * 8;
     iss.MaxValueOut = frac_1;
     iss.WidthOut = (int)ceil(fabs(dst_xy.x));
-    iss.HeightOut = (int)ceil(fabs(dst_xy.y));
+    iss.HeightOut = fixed2int_pixround_perfect((fixed)((int64_t)(penum->rect.y + penum->rect.h) * 
+						penum->dst_height / penum->Height))
+	- fixed2int_pixround_perfect((fixed)((int64_t)penum->rect.y * penum->dst_height / penum->Height));
+    iss.HeightOut = any_abs(iss.HeightOut);
     iss.WidthIn = penum->rect.w;
     iss.HeightIn = penum->rect.h;
+    iss.src_y_offset = penum->rect.y;
+    iss.EntireWidthIn = penum->Width;
+    iss.EntireHeightIn = penum->Height;
+    iss.EntireWidthOut = fixed2int_pixround(any_abs(penum->dst_width));
+    iss.EntireHeightOut = fixed2int_pixround(any_abs(penum->dst_height));
     pccs = cs_concrete_space(pcs, pis);
     iss.Colors = cs_num_components(pccs);
     if (penum->bps <= 8 && penum->device_color) {
@@ -184,7 +194,9 @@ gs_image_class_0_interpolate(gx_image_enum * penum)
 	    dda_advance(x0, penum->rect.w);
 	penum->xyi.x = fixed2int_pixround(dda_current(x0));
     }
-    penum->xyi.y = fixed2int_pixround(dda_current(penum->dda.pixel0.y));
+    penum->xyi.y = penum->yi0 + fixed2int_pixround_perfect((fixed)((int64_t)penum->rect.y 
+				    * penum->dst_height / penum->Height))
+		* (penum->matrix.yy > 0 ? 1 : -1);
     if_debug0('b', "[b]render=interpolate\n");
     return &image_render_interpolate;
 }
@@ -336,12 +348,14 @@ image_render_interpolate(gx_image_enum * penum, const byte * buffer,
 			    case 1:
 				do {
 				    LINE_ACCUM(color, bpp);
+				    vd_pixel(int2fixed(x), int2fixed(ry), color);
 				    x++, psrc += 1;
 				} while (x < xe && psrc[-1] == psrc[0]);
 				break;
 			    case 3:
 				do {
 				    LINE_ACCUM(color, bpp);
+				    vd_pixel(int2fixed(x), int2fixed(ry), color);
 				    x++, psrc += 3;
 				} while (x < xe && psrc[-4] == psrc[0] &&
 				     psrc[-3] == psrc[1] && psrc[-2] == psrc[2] &&
@@ -373,6 +387,7 @@ image_render_interpolate(gx_image_enum * penum, const byte * buffer,
 		    }
 		}
 		LINE_ACCUM_COPY(dev, out, bpp, xo, x, raster, ry);
+		/*if_debug1('w', "[w]Y=%d:\n", ry);*/ /* See siscale.c about 'w'. */
 		penum->line_xy++;
 		if_debug0('B', "\n");
 	    }
