@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: gxpflat.c,v 1.10 2007/09/11 15:23:48 Arabidopsis Exp $ */
+/* $Id: gxpflat.c,v 1.11 2008/03/23 15:28:00 Arabidopsis Exp $ */
 /* Path flattening algorithms */
 #include "string_.h"
 #include "gx.h"
@@ -106,7 +106,7 @@ gx_curve_log2_samples(fixed x0, fixed y0, const curve_segment * pc,
  * Curve and Surface Representation," B. A. Barsky and A. D. DeRose, IEEE,
  * 1985, courtesy of Crispin Goswell.
  */
-private void
+static void
 split_curve_midpoint(fixed x0, fixed y0, const curve_segment * pc,
 		     curve_segment * pc1, curve_segment * pc2)
 {				/*
@@ -139,7 +139,7 @@ split_curve_midpoint(fixed x0, fixed y0, const curve_segment * pc,
 #undef midpoint
 }
 
-private inline void
+static inline void
 print_points(const gs_fixed_point *points, int count)
 {
 #ifdef DEBUG    
@@ -271,7 +271,7 @@ gx_flattened_iterator__init(gx_flattened_iterator *this,
     return true;
 }
 
-private inline bool 
+static inline bool 
 check_diff_overflow(fixed v0, fixed v1)
 {
     if (v0 < v1) {
@@ -341,7 +341,7 @@ gx_flattened_iterator__init_line(gx_flattened_iterator *this,
 }
 
 #ifdef DEBUG
-private inline void
+static inline void
 gx_flattened_iterator__print_state(gx_flattened_iterator *this)
 {
     if (!gs_debug_c('3'))
@@ -457,7 +457,7 @@ last:
     return false;
 }
 
-private inline void
+static inline void
 gx_flattened_iterator__unaccum(gx_flattened_iterator *this)
 {
 #   define unaccum(i, r, di, dr, rmask)\
@@ -533,7 +533,7 @@ gx_flattened_iterator__switch_to_backscan(gx_flattened_iterator *this, bool not_
 
 #define max_points 50		/* arbitrary */
 
-private int
+static int
 generate_segments(gx_path * ppath, const gs_fixed_point *points, 
 		    int count, segment_notes notes)
 {
@@ -556,7 +556,7 @@ generate_segments(gx_path * ppath, const gs_fixed_point *points,
     }
 }
 
-private int
+static int
 gx_subdivide_curve_rec(gx_flattened_iterator *this, 
 		  gx_path * ppath, int k, curve_segment * pc,
 		  segment_notes notes, gs_fixed_point *points)
