@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: igcref.c,v 1.11 2008/03/23 15:27:42 Arabidopsis Exp $ */
+/* $Id: igcref.c,v 1.12 2008/05/04 14:34:44 Arabidopsis Exp $ */
 /* ref garbage collector for Ghostscript */
 #include "memory_.h"
 #include "ghost.h"
@@ -417,7 +417,7 @@ igc_reloc_refs(ref_packed * from, ref_packed * to, gc_state_t * gcst)
 	/* The following assignment is logically unnecessary; */
 	/* we do it only for convenience in debugging. */
 	pref = (ref *) rp;
-	if_debug3('8', "  [8]relocating %s %d ref at 0x%lx",
+	if_debug3('8', "  [8]relocating %s %d ref at 0x%lx\n",
 		  (r_has_attr(pref, l_mark) ? "marked" : "unmarked"),
 		  r_btype(pref), (ulong) pref);
 	if ((r_has_attr(pref, l_mark) || do_all) &&
@@ -545,10 +545,10 @@ igc_reloc_refs(ref_packed * from, ref_packed * to, gc_state_t * gcst)
 		default:
 		    goto no_reloc; /* don't print trace message */
 	    }
-	    if_debug2('8', ", 0x%lx => 0x%lx", (ulong)before, (ulong)after);
+	    if_debug2('8', "  [8]relocated 0x%lx => 0x%lx\n",
+		      (ulong)before, (ulong)after);
 	}
 no_reloc:
-	if_debug0('8', "\n");
 	rp += packed_per_ref;
     }
 }
