@@ -17,12 +17,12 @@
 
 */
 
-/* $Id: siscale.c,v 1.9 2008/03/23 15:27:41 Arabidopsis Exp $ */
+/* $Id: siscale.c,v 1.10 2008/05/04 14:34:43 Arabidopsis Exp $ */
 /* Image scaling filters */
 #include "math_.h"
 #include "memory_.h"
 #include "stdio_.h"
-#include "gconfigv.h"
+#include "stdint_.h"
 #include "gdebug.h"
 #include "strimpl.h"
 #include "siscale.h"
@@ -34,38 +34,6 @@
 
 /* ---------------- ImageScaleEncode/Decode ---------------- */
 
-/* Define whether to accumulate pixels in fixed or floating point. */
-#if USE_FPU <= 0
-
-	/* Accumulate pixels in fixed point. */
-
-typedef int PixelWeight;
-
-#  if ARCH_INTS_ARE_SHORT
-typedef long AccumTmp;
-#  else
-typedef int AccumTmp;
-#  endif
-
-/*
- *    The optimal scaling for fixed point arithmetic is a function of the
- *    size of AccumTmp type, the size if the input pixel, the size of the
- *    intermediate pixel (PixelTmp) and the size of the output pixel.  This
- *    is set by these definitions and the fraction_bits variables in the
- *    functions.
- */
-#define num_weight_bits\
-  ((sizeof(AccumTmp) - maxSizeofPixel) * 8 - (LOG2_MAX_ISCALE_SUPPORT + 1))
-#define numScaleBits  ((maxSizeofPixel - sizeof(PixelTmp)) * 8 )
-#define fixedScaleFactor  ((int) (1 << numScaleBits))
-#define scale_PixelWeight(factor) ((int)((factor) * (1 << num_weight_bits)))
-#define unscale_AccumTmp(atemp, fraction_bits) arith_rshift(atemp, fraction_bits)
-#define NEED_FRACTION_BITS
-
-#else /* USE_FPU > 0 */
-
-	/* Accumulate pixels in floating point. */
-
 typedef float PixelWeight;
 typedef double AccumTmp;
 
@@ -75,8 +43,6 @@ typedef double AccumTmp;
 #define unscale_AccumTmp(atemp, fraction_bits) ((int)(atemp + 0.5))
 /*#undef NEED_FRACTION_BITS*/
 
-#endif /* USE_FPU */
-
 /* Temporary intermediate values */
 typedef byte PixelTmp;
 typedef int PixelTmp2;		/* extra width for clamping sum */
@@ -109,7 +75,6 @@ typedef struct stream_IScale_state_s {
     /* The init procedure sets the following. */
     int sizeofPixelIn;		/* bytes per input value, 1 or 2 */
     int sizeofPixelOut;		/* bytes per output value, 1 or 2 */
-    double xscale, yscale;
     void /*PixelIn */ *src;
     void /*PixelOut */ *dst;
     PixelTmp *tmp;
@@ -119,6 +84,7 @@ typedef struct stream_IScale_state_s {
     int src_y;
     uint src_offset, src_size;
     int dst_y;
+    int src_y_offset;
     uint dst_offset, dst_size;
     CLIST dst_next_list;	/* for next output value */
     int dst_last_index;		/* highest index used in list */
@@ -199,8 +165,14 @@ calculate_contrib(
 		     CONTRIB * items,
 	/* The output image is scaled by 'scale' relative to the input. */
 		     double scale,
-	/* Start generating weights for input pixel 'input_index'. */
-		     int input_index,
+	/* Start generating weights for input pixel 'starting_output_index'. */
+		     int starting_output_index,
+	/* Offset of input subimage from the input image start. */
+		     int src_y_offset,
+	/* Entire output image size. */
+		     int dst_size,
+	/* Entire input image size. */
+		     int src_size,
 	/* Generate 'size' weight lists. */
 		     int size,
 	/* Limit pixel indices to 'limit', for clamping at the edges */
@@ -222,6 +194,7 @@ calculate_contrib(
     int i, j;
     int last_index = -1;
 
+    if_debug1('w', "[w]calculate_contrib scale=%lg\n", scale);
     if (scale < 1.0) {
 	double clamped_scale = max(scale, min_scale);
 
@@ -236,32 +209,34 @@ calculate_contrib(
     npixels = (int)(WidthIn * 2 + 1);
 
     for (i = 0; i < size; ++i) {
-	double center = (input_index + i) / scale;
-	int left = (int)ceil(center - WidthIn);
-	int right = (int)floor(center + WidthIn);
-
-	/*
-	 * In pathological cases, the limit may be much less
-	 * than the support.  We do need to deal with this.
+	/* Here we need :
+	   double scale = (double)dst_size / src_size;
+	   float dst_offset_fraction = floor(dst_offset) - dst_offset;
+	   double center = (starting_output_index  + i + dst_offset_fraction + 0.5) / scale - 0.5;
+	   int left = (int)ceil(center - WidthIn);
+	   int right = (int)floor(center + WidthIn);
+	   We can't compute 'right' in floats because float arithmetics is not associative.
+	   In older versions tt caused a 1 pixel bias of image bands due to 
+	   rounding direction appears to depend on src_y_offset. So compute in rationals.
+	   Since pixel center fall to half integers, we subtract 0.5 
+	   in the image space and add 0.5 in the device space.
 	 */
-#define clamp_pixel(j)\
-  (j < 0 ? (-j >= limit ? limit - 1 : -j) :\
-   j >= limit ? (j >> 1 >= limit ? 0 : (limit - j) + limit - 1) :\
-   j)
-	int lmin =
-	(left < 0 ? 0 : left);
-	int lmax =
-	(left < 0 ? (-left >= limit ? limit - 1 : -left) : left);
-	int rmin =
-	(right >= limit ?
-	 (right >> 1 >= limit ? 0 : (limit - right) + limit - 1) :
-	 right);
-	int rmax =
-	(right >= limit ? limit - 1 : right);
-	int first_pixel = min(lmin, rmin);
-	int last_pixel = max(lmax, rmax);
+	int dst_y_offset_fraction_num = (int)((int64_t)src_y_offset * dst_size % src_size) * 2 <= src_size
+			? -(int)((int64_t)src_y_offset * dst_size % src_size)
+			: src_size - (int)((int64_t)src_y_offset * dst_size % src_size);
+	int center_denom = dst_size * 2; 
+	int64_t center_num = /* center * center_denom * 2 = */ 
+	    (starting_output_index  + i) * src_size * 2 + src_size + dst_y_offset_fraction_num * 2 - dst_size;
+	int left = (int)ceil((center_num - WidthIn * center_denom) / center_denom);
+	int right = (int)floor((center_num + WidthIn * center_denom) / center_denom);
+	double center = (double)center_num / center_denom;
+#define clamp_pixel(j) (j < 0 ? 0 : j >= limit ? limit - 1 : j)
+	int first_pixel = clamp_pixel(left);
+	int last_pixel = clamp_pixel(right);
 	CONTRIB *p;
 
+	if_debug4('w', "[w]i=%d, i+offset=%lg scale=%lg center=%lg : ", starting_output_index + i, 
+		starting_output_index + i + (double)src_y_offset / src_size * dst_size, scale, center);
 	if (last_pixel > last_index)
 	    last_index = last_pixel;
 	contrib[i].first_pixel = (first_pixel % modulus) * stride;
@@ -281,6 +256,7 @@ calculate_contrib(
 
                 p[k].weight +=
 		    (PixelWeight) (weight * scaled_factor);
+		if_debug2('w', " %d %f", k, (float)p[k].weight);
 	    }
 
 	} else {
@@ -294,8 +270,10 @@ calculate_contrib(
 
 		p[k].weight +=
 		    (PixelWeight) (weight * scaled_factor);
+		if_debug2('w', " %d %f", k, (float)p[k].weight);
 	    }
 	}
+	if_debug0('w', "\n");
     }
     return last_index;
 }
@@ -342,7 +320,7 @@ zoom_x(PixelTmp * tmp, const void /*PixelIn */ *src, int sizeofPixelIn,
 			  }\
 			}\
 			{ PixelIn2 pixel = unscale_AccumTmp(weight, fraction_bits);\
-			  if_debug1('W', " %ld", (long)pixel);\
+			  if_debug1('W', " %lx", (long)pixel);\
 			  *tp =\
 			    (PixelTmp)CLAMP(pixel, minPixelTmp, maxPixelTmp);\
 			}\
@@ -395,7 +373,7 @@ zoom_y(void /*PixelOut */ *dst, int sizeofPixelOut, uint MaxValueOut,
 		    weight += *pp * cp->weight;\
 		}\
 		{ PixelTmp2 pixel = unscale_AccumTmp(weight, fraction_bits);\
-		  if_debug1('W', " %d", pixel);\
+		  if_debug1('W', " %lx", (long)pixel);\
 		  ((PixelOut *)dst)[kc] =\
 		    (PixelOut)CLAMP(pixel, 0, max_weight);\
 		}\
@@ -404,7 +382,21 @@ zoom_y(void /*PixelOut */ *dst, int sizeofPixelOut, uint MaxValueOut,
     if (sizeofPixelOut == 1) {
 	zoom_y_loop(byte)
     } else {			/* sizeofPixelOut == 2 */
-	zoom_y_loop(bits16)
+	/* zoom_y_loop(bits16) */
+	for ( kc = 0; kc < kn; ++kc ) {
+		AccumTmp weight = 0;
+		{ const PixelTmp *pp = &tmp[kc + first_pixel];
+		  int j = cn;
+		  const CONTRIB *cp = cbp;
+		  for ( ; j > 0; pp += kn, ++cp, --j )
+		    weight += *pp * cp->weight;
+		}
+		{ PixelTmp2 pixel = unscale_AccumTmp(weight, fraction_bits);
+		  if_debug1('W', " %lx", (long)pixel);
+		  ((bits16 *)dst)[kc] =
+		    (bits16)CLAMP(pixel, 0, max_weight);
+		}
+	}
     }
     if_debug0('W', "\n");
 }
@@ -423,33 +415,34 @@ calculate_dst_contrib(stream_IScale_state * ss, int y)
 {
     uint row_size = ss->params.WidthOut * ss->params.Colors;
     int last_index =
-    calculate_contrib(&ss->dst_next_list, ss->dst_items, ss->yscale,
-		      y, 1, ss->params.HeightIn, MAX_ISCALE_SUPPORT, row_size,
+    calculate_contrib(&ss->dst_next_list, ss->dst_items, 
+		      (double)ss->params.EntireHeightOut / ss->params.EntireHeightIn,
+		      y, ss->src_y_offset, ss->params.EntireHeightOut, ss->params.EntireHeightIn, 
+		      1, ss->params.HeightIn, MAX_ISCALE_SUPPORT, row_size,
 		      (double)ss->params.MaxValueOut / (fixedScaleFactor * unitPixelTmp) );
     int first_index_mod = ss->dst_next_list.first_pixel / row_size;
 
+    if_debug2('w', "[W]calculate_dst_contrib for y = %d, y+offset=%d\n", y, y + ss->src_y_offset);
     ss->dst_last_index = last_index;
     last_index %= MAX_ISCALE_SUPPORT;
     if (last_index < first_index_mod) {		/* Shuffle the indices to account for wraparound. */
 	CONTRIB shuffle[MAX_ISCALE_SUPPORT];
 	int i;
 
-	for (i = 0; i < MAX_ISCALE_SUPPORT; ++i)
+	for (i = 0; i < MAX_ISCALE_SUPPORT; ++i) {
 	    shuffle[i].weight =
 		(i <= last_index ?
 		 ss->dst_items[i + MAX_ISCALE_SUPPORT - first_index_mod].weight :
 		 i >= first_index_mod ?
 		 ss->dst_items[i - first_index_mod].weight :
 		 0);
+	    if_debug1('W', " %f", shuffle[i].weight);
+	}
 	memcpy(ss->dst_items, shuffle, MAX_ISCALE_SUPPORT * sizeof(CONTRIB));
 	ss->dst_next_list.n = MAX_ISCALE_SUPPORT;
 	ss->dst_next_list.first_pixel = 0;
     }
-#ifdef DEBUG
-    if (gs_debug_c('w')) {
-	dprintf1("[w]calc dest contrib for y = %d\n", y);
-    }
-#endif
+    if_debug0('W', "\n");
 }
 
 /* Set default parameter values (actually, just clear pointers). */
@@ -474,13 +467,12 @@ s_IScale_init(stream_state * st)
 
     ss->sizeofPixelIn = ss->params.BitsPerComponentIn / 8;
     ss->sizeofPixelOut = ss->params.BitsPerComponentOut / 8;
-    ss->xscale = (double)ss->params.WidthOut / (double)ss->params.WidthIn;
-    ss->yscale = (double)ss->params.HeightOut / (double)ss->params.HeightIn;
 
     ss->src_y = 0;
     ss->src_size = ss->params.WidthIn * ss->sizeofPixelIn * ss->params.Colors;
     ss->src_offset = 0;
     ss->dst_y = 0;
+    ss->src_y_offset = ss->params.src_y_offset;
     ss->dst_size = ss->params.WidthOut * ss->sizeofPixelOut * ss->params.Colors;
     ss->dst_offset = 0;
 
@@ -493,7 +485,8 @@ s_IScale_init(stream_state * st)
 					   max(ss->params.WidthOut, ss->params.HeightOut),
 				      sizeof(CLIST), "image_scale contrib");
     ss->items = (CONTRIB *) gs_alloc_byte_array(mem,
-				  contrib_pixels(ss->xscale) * ss->params.WidthOut,
+				  contrib_pixels((double)ss->params.EntireWidthOut / 
+					ss->params.EntireWidthIn) * ss->params.WidthOut,
 				 sizeof(CONTRIB), "image_scale contrib[*]");
     /* Allocate buffers for 1 row of source and destination. */
     ss->dst = gs_alloc_byte_array(mem, ss->params.WidthOut * ss->params.Colors,
@@ -508,8 +501,10 @@ s_IScale_init(stream_state * st)
 /****** WRONG ******/
     }
     /* Pre-calculate filter contributions for a row. */
-    calculate_contrib(ss->contrib, ss->items, ss->xscale,
-		      0, ss->params.WidthOut, ss->params.WidthIn, ss->params.WidthIn,
+    calculate_contrib(ss->contrib, ss->items,
+		      (double)ss->params.EntireWidthOut / ss->params.EntireWidthIn,
+		      0, 0, ss->params.WidthOut, ss->params.WidthIn, 
+		      ss->params.WidthOut, ss->params.WidthIn, ss->params.WidthIn,
 		      ss->params.Colors, (double)unitPixelTmp * fixedScaleFactor / ss->params.MaxValueIn);
 
     /* Prepare the weights for the first output row. */
@@ -553,7 +548,8 @@ s_IScale_process(stream_state * st, stream_cursor_read * pr,
 	    /* inter-assigned freely, but not compared! */
 	    if ((void *)row != ss->dst)		/* no buffering */
 		goto adv;
-	} {			/* We're delivering a buffered output row. */
+	} 
+	{			/* We're delivering a buffered output row. */
 	    uint wcount = ss->dst_size - ss->dst_offset;
 	    uint ncopy = min(wleft, wcount);
 
@@ -565,7 +561,7 @@ s_IScale_process(stream_state * st, stream_cursor_read * pr,
 	    ss->dst_offset = 0;
 	}
 	/* Advance to the next output row. */
-      adv:++(ss->dst_y);
+      adv:++ss->dst_y;
 	if (ss->dst_y != ss->params.HeightOut)
 	    calculate_dst_contrib(ss, ss->dst_y);
     }
