@@ -17,7 +17,7 @@
 
 */
 
-/* $Id: sjpx_luratech.c,v 1.4 2007/09/11 15:23:57 Arabidopsis Exp $ */
+/* $Id: sjpx_luratech.c,v 1.5 2008/03/23 15:28:00 Arabidopsis Exp $ */
 /* JPXDecode filter implementation -- hooks in the Luratech JPEG2K CSDK */
  
 #include "memory_.h"
@@ -56,7 +56,7 @@ private_st_jpxd_state(); /* creates a gc object for our state,
 /** callback for the codec library */
 
 /* memory allocation */
-private void * JP2_Callback_Conv
+static void * JP2_Callback_Conv
 s_jpx_alloc(long size, JP2_Callback_Param param)
 {
     void *result = malloc(size);
@@ -65,7 +65,7 @@ s_jpx_alloc(long size, JP2_Callback_Param param)
 }
 
 /* memory free */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpx_free(void *ptr, JP2_Callback_Param param)
 {
     free(ptr);
@@ -74,7 +74,7 @@ s_jpx_free(void *ptr, JP2_Callback_Param param)
 }
 
 /* pass any available input to the library */
-private unsigned long JP2_Callback_Conv
+static unsigned long JP2_Callback_Conv
 s_jpxd_read_data(unsigned char *pucData,
 			    unsigned long ulPos, unsigned long ulSize, 
 			    JP2_Callback_Param param)
@@ -88,7 +88,7 @@ s_jpxd_read_data(unsigned char *pucData,
 }
 
 /* write decompressed data into our image buffer */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxd_write_data(unsigned char * pucData,
 			       short sComponent,
 			       unsigned long ulRow,
@@ -123,7 +123,7 @@ s_jpxd_write_data(unsigned char * pucData,
     return cJP2_Error_OK;
 }
 
-private int
+static int
 s_jpxd_inbuf(stream_jpxd_state *state, stream_cursor_read * pr)
 {
     long in_size = pr->limit - pr->ptr;
@@ -167,7 +167,7 @@ s_jpxd_inbuf(stream_jpxd_state *state, stream_cursor_read * pr)
    this involves allocating the stream and image structures, and
    initializing the decoder.
  */
-private int
+static int
 s_jpxd_init(stream_state * ss)
 {
     stream_jpxd_state *const state = (stream_jpxd_state *) ss;
@@ -194,7 +194,7 @@ s_jpxd_init(stream_state * ss)
 /* process a secton of the input and return any decoded data.
    see strimpl.h for return codes.
  */
-private int
+static int
 s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
                  stream_cursor_write * pw, bool last)
 {
@@ -386,7 +386,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 /* stream release.
    free all our decoder state.
  */
-private void
+static void
 s_jpxd_release(stream_state *ss)
 {
     stream_jpxd_state *const state = (stream_jpxd_state *) ss;
@@ -420,7 +420,7 @@ const stream_template s_jpxd_template = {
 private_st_jpxe_state();
 
 /* callback for uncompressed data input */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxe_read(unsigned char *buffer, short component,
 		unsigned long row, unsigned long start,
 		unsigned long num, JP2_Callback_Param param)
@@ -456,7 +456,7 @@ s_jpxe_read(unsigned char *buffer, short component,
 }
 
 /* callback for compressed data output */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxe_write(unsigned char *buffer,
 		unsigned long pos, unsigned long size,
 		JP2_Callback_Param param)
@@ -499,7 +499,7 @@ s_jpxe_write(unsigned char *buffer,
 }
 
 /* set defaults for user-configurable parameters */
-private void
+static void
 s_jpxe_set_defaults(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
@@ -513,7 +513,7 @@ s_jpxe_set_defaults(stream_state *ss)
 }
 
 /* initialize the stream */
-private int
+static int
 s_jpxe_init(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
@@ -661,7 +661,7 @@ s_jpxe_init(stream_state *ss)
 
 /* process input and return any encoded data.
    see strimpl.h for return codes. */
-private int
+static int
 s_jpxe_process(stream_state *ss, stream_cursor_read *pr,
 		stream_cursor_write *pw, bool last)
 {
@@ -744,7 +744,7 @@ s_jpxe_process(stream_state *ss, stream_cursor_read *pr,
 }
 
 /* stream release. free all our state. */
-private void
+static void
 s_jpxe_release(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
